==> nextcloud-22.2.10.tgz: nextcloud/apps/files/l10n/lb.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Späicherplaatz temporär net erreeschbar",
    "Storage invalid" : "Späicherplatz net gülteg",
    "Unknown error" : "Et ass en onbekannte Fehler opgetrueden",
    "File could not be found" : "Datei konnt net fonnt ginn",
    "Download" : "Download",
    "Delete" : "Läschen",
    "Home" : "Doheem",
    "Close" : "Zoumaachen",
    "Favorites" : "Favoriten",
    "Could not create folder \"{dir}\"" : "Dossier \"{dir}\" konnt net erstallt ginn",
    "Upload cancelled." : "Upload ofgebrach.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "{filename} konnt eropgelueden ginn, well et een Dossier ass oder d'Datei 0 Bytes huet",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Net genuch Späicher, du probéiers {size1} eropzelueden, et ass awer nëmmen méi {size2} fräi",
    "Target folder \"{dir}\" does not exist any more" : "Den Dossier \"{dir}\" existéiert net méi",
    "Not enough free space" : "Nët genuch Späicherplaatz",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} vun {totalSize} ({bitrate})",
    "Actions" : "Aktiounen",
    "Rename" : "Ëmbenennen",
    "Delete folder" : "Dossier läschen",
    "Disconnect storage" : "Net connectéierten Späicher",
    "Could not load info for file \"{file}\"" : "Et konnten keng Informatiounen zu {file} gelueden ginn",
    "Files" : "Dateien",
    "Details" : "Detailer",
    "Pending" : "Ausstoend",
    "Unable to determine date" : "Datum kann net festgestallt ginn",
    "This operation is forbidden" : "Dës Operatioun ass verbueden.",
    "This directory is unavailable, please check the logs or contact the administrator" : "Dësen Dossier ass net disponibel, w.e.g. kontrolléiert d'Logs oder kontaktéiert den Administrateur",
    "Could not move \"{file}\", target exists" : "\"{file}\" konnt beweegt ginn. Et existéiert do schonn.",
    "Could not move \"{file}\"" : "\"{file}\" konnt verreckelt ginn",
    "{newName} already exists" : "{newName} gett et schon",
    "Could not rename \"{fileName}\", it does not exist any more" : "\"{fileName}\" konnt embenannt ginn, well et net méi existéiert",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "\"{targetName}\" konnt net gesat ginn, well dësen schon am Dossier \"{dir}\" existéiert. Wiel weg. een aaneren",
    "Could not rename \"{fileName}\"" : "\"{fileName}\" konnt net embenannt ginn",
    "Could not create file \"{file}\"" : "\"{file}\" konnt net erstallt ginn",
    "Could not create file \"{file}\" because it already exists" : "\"{file}\" konnt net erstallt ginn, well des schon existéiert",
    "Could not create folder \"{dir}\" because it already exists" : "Den Dossier \"{dir}\" konnt net erstallt ginn, well desen schon existéiert",
    "Error deleting file \"{fileName}\"." : "Fehler beim läschen vun \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Keng Resultater an aneren Dossieren fir {tag}{filter}{endtag} fonnt",
    "Name" : "Numm",
    "Size" : "Gréisst",
    "Modified" : "Geännert",
    "_%n folder_::_%n folders_" : ["¦%n Dossier","¦%n Dossieren"],
    "_%n file_::_%n files_" : ["¦%n Datei","¦%n Dateien"],
    "{dirs} and {files}" : "{dirs} an {files}",
    "_including %n hidden_::_including %n hidden_" : ["Beinhaltet ¦%n verstoppte Saach","Beinhaltet ¦%n verstoppte Saachen"],
    "_Uploading %n file_::_Uploading %n files_" : ["Am Gaangen ¦%n Datei eropzelueden","Am Gaangen ¦%n Dateien eropzelueden"],
    "New" : "Nei",
    "\"{name}\" is an invalid file name." : "\"{name}\" ass een ongültegen Numm",
    "File name cannot be empty." : "D'Datei kann net eidel sinn",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" ass een ongültegen Typ vun Datei",
    "View in folder" : "Kuk am Dossier ",
    "Copied!" : "Kopéiert!",
    "Path" : "Pad",
    "_%n byte_::_%n bytes_" : ["¦%n Byte","¦%n Byte"],
    "Favorited" : "Favoriséiert",
    "Favorite" : "Favorit",
    "New folder" : "Neien Dossier",
    "Upload file" : "Upload file",
    "Recent" : "Rezent",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Add to favorites",
    "An error occurred while trying to update the tags" : "Beim Updaten vun den Tags ass e Fehler entstaanen",
    "Added to favorites" : "Zu den Favoriten dobaigesat",
    "Removed from favorites" : "Vun den Favoriten eweggeholl",
    "You added {file} to your favorites" : "Du hues {file} zu denger Favortiten dobäigesat",
    "You removed {file} from your favorites" : "Du hues {file} aus dengen Favortiten geläscht",
    "File changes" : "Datei Ännerungen",
    "Created by {user}" : "Erstallt vum {user}",
    "Changed by {user}" : "Geännert vum {user}",
    "Deleted by {user}" : "Geläscht vum {user}",
    "Restored by {user}" : "Erem hier gestallt vum {user}",
    "Renamed by {user}" : "Embenannt vum {user}",
    "Moved by {user}" : "Beweegt vum {user}",
    "\"remote user\"" : "\"Remote-Benotzer\"",
    "You created {file}" : "Du hues {file} erstallt",
    "{user} created {file}" : "Den {user} huet {file} erstallt",
    "{file} was created in a public folder" : "{file} ass an engem ëffentlechen Dossier erstallt ginn",
    "You changed {file}" : "Du hues {file} verännert",
    "{user} changed {file}" : "Den {user} huet {file} verännert",
    "You deleted {file}" : "Du hues {file} geläscht",
    "{user} deleted {file}" : "Den {user} huet {file} geläscht",
    "You restored {file}" : "Du hues {file} erem hier gestallt",
    "{user} restored {file}" : "Den {user} huet {file} erem hier gestallt",
    "You renamed {oldfile} to {newfile}" : "Du hues {oldfile} zu {newfile} embenannt",
    "{user} renamed {oldfile} to {newfile}" : "Den {user} huet {oldfile} zu {newfile} embenannt",
    "You moved {oldfile} to {newfile}" : "Du hues {oldfile} zu {newfile} verreckelt",
    "{user} moved {oldfile} to {newfile}" : "Den {user} huet {oldfile} zu {newfile} verreckelt",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Eng Datei gouf zu dengen Favoriten <strong> dobäigesat </strong> oder aus dengen Favortien <strong> geläscht </strong>",
    "All files" : "All d'Fichieren",
    "Upload (max. %s)" : "Upload (maximal ¦%s)",
    "in %s" : "an %s",
    "Tags" : "Tags",
    "Cancel" : "Ofbriechen",
    "Create" : "Erstellen",
    "Settings" : "Astellungen",
    "Show hidden files" : "Weis déi verstoppten Dateien",
    "WebDAV" : "WebDAV",
    "No files in here" : "Keng Dokumenter hei",
    "Upload some content or sync with your devices!" : "Lued Dateien erop oder synchroniséier se mat dengen Appartaten",
    "No entries found in this folder" : "Keng Elementer an dësem Dossier fonnt",
    "Select all" : "All auswielen",
    "Upload too large" : "Upload ze grouss",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Déi Dateien déi Dir probéiert erop ze lueden sinn méi grouss wei déi Maximal Gréisst déi op dësem Server erlaabt ass.",
    "Files and folders you mark as favorite will show up here" : "Hei gesais du deng Favoriten",
    "Deleted files" : "Geläschten Dateien",
    "Shared with others" : "Mat aaneren gedeelt",
    "Shared with you" : "Mat dir gedeelt",
    "Shared by link" : "Mat engem Link gedeelt",
    "Text file" : "Text Fichier",
    "New text file.txt" : "Neien Text file.txt",
    "Select" : "Auswielen",
    "You don’t have permission to upload or create files here" : "Du hues net genuch Rechter hei Dokumenter eropzelueden oder ze erstellen"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-23.0.8.tgz: nextcloud/apps/files/l10n/lb.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Späicherplaatz temporär net erreeschbar",
    "Storage invalid" : "Späicherplatz net gülteg",
    "Unknown error" : "Et ass en onbekannte Fehler opgetrueden",
    "File could not be found" : "Datei konnt net fonnt ginn",
    "Download" : "Download",
    "Delete" : "Läschen",
    "Home" : "Doheem",
    "Close" : "Zoumaachen",
    "Favorites" : "Favoriten",
    "Could not create folder \"{dir}\"" : "Dossier \"{dir}\" konnt net erstallt ginn",
    "Upload cancelled." : "Upload ofgebrach.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "{filename} konnt eropgelueden ginn, well et een Dossier ass oder d'Datei 0 Bytes huet",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Net genuch Späicher, du probéiers {size1} eropzelueden, et ass awer nëmmen méi {size2} fräi",
    "Target folder \"{dir}\" does not exist any more" : "Den Dossier \"{dir}\" existéiert net méi",
    "Not enough free space" : "Nët genuch Späicherplaatz",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} vun {totalSize} ({bitrate})",
    "Actions" : "Aktiounen",
    "Rename" : "Ëmbenennen",
    "Delete folder" : "Dossier läschen",
    "Disconnect storage" : "Net connectéierten Späicher",
    "Could not load info for file \"{file}\"" : "Et konnten keng Informatiounen zu {file} gelueden ginn",
    "Files" : "Dateien",
    "Details" : "Detailer",
    "Pending" : "Ausstoend",
    "Unable to determine date" : "Datum kann net festgestallt ginn",
    "This operation is forbidden" : "Dës Operatioun ass verbueden.",
    "This directory is unavailable, please check the logs or contact the administrator" : "Dësen Dossier ass net disponibel, w.e.g. kontrolléiert d'Logs oder kontaktéiert den Administrateur",
    "Could not move \"{file}\", target exists" : "\"{file}\" konnt beweegt ginn. Et existéiert do schonn.",
    "Could not move \"{file}\"" : "\"{file}\" konnt verreckelt ginn",
    "{newName} already exists" : "{newName} gett et schon",
    "Could not rename \"{fileName}\", it does not exist any more" : "\"{fileName}\" konnt embenannt ginn, well et net méi existéiert",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "\"{targetName}\" konnt net gesat ginn, well dësen schon am Dossier \"{dir}\" existéiert. Wiel weg. een aaneren",
    "Could not rename \"{fileName}\"" : "\"{fileName}\" konnt net embenannt ginn",
    "Could not create file \"{file}\"" : "\"{file}\" konnt net erstallt ginn",
    "Could not create file \"{file}\" because it already exists" : "\"{file}\" konnt net erstallt ginn, well des schon existéiert",
    "Could not create folder \"{dir}\" because it already exists" : "Den Dossier \"{dir}\" konnt net erstallt ginn, well desen schon existéiert",
    "Error deleting file \"{fileName}\"." : "Fehler beim läschen vun \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Keng Resultater an aneren Dossieren fir {tag}{filter}{endtag} fonnt",
    "Name" : "Numm",
    "Size" : "Gréisst",
    "Modified" : "Geännert",
    "_%n folder_::_%n folders_" : ["¦%n Dossier","¦%n Dossieren"],
    "_%n file_::_%n files_" : ["¦%n Datei","¦%n Dateien"],
    "{dirs} and {files}" : "{dirs} an {files}",
    "_including %n hidden_::_including %n hidden_" : ["Beinhaltet ¦%n verstoppte Saach","Beinhaltet ¦%n verstoppte Saachen"],
    "_Uploading %n file_::_Uploading %n files_" : ["Am Gaangen ¦%n Datei eropzelueden","Am Gaangen ¦%n Dateien eropzelueden"],
    "\"{name}\" is an invalid file name." : "\"{name}\" ass een ongültegen Numm",
    "File name cannot be empty." : "D'Datei kann net eidel sinn",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" ass een ongültegen Typ vun Datei",
    "View in folder" : "Kuk am Dossier ",
    "Copied!" : "Kopéiert!",
    "Path" : "Pad",
    "_%n byte_::_%n bytes_" : ["¦%n Byte","¦%n Byte"],
    "Favorited" : "Favoriséiert",
    "Favorite" : "Favorit",
    "New folder" : "Neien Dossier",
    "Upload file" : "Upload file",
    "Recent" : "Rezent",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Add to favorites",
    "An error occurred while trying to update the tags" : "Beim Updaten vun den Tags ass e Fehler entstaanen",
    "Added to favorites" : "Zu den Favoriten dobaigesat",
    "Removed from favorites" : "Vun den Favoriten eweggeholl",
    "You added {file} to your favorites" : "Du hues {file} zu denger Favortiten dobäigesat",
    "You removed {file} from your favorites" : "Du hues {file} aus dengen Favortiten geläscht",
    "File changes" : "Datei Ännerungen",
    "Created by {user}" : "Erstallt vum {user}",
    "Changed by {user}" : "Geännert vum {user}",
    "Deleted by {user}" : "Geläscht vum {user}",
    "Restored by {user}" : "Erem hier gestallt vum {user}",
    "Renamed by {user}" : "Embenannt vum {user}",
    "Moved by {user}" : "Beweegt vum {user}",
    "\"remote user\"" : "\"Remote-Benotzer\"",
    "You created {file}" : "Du hues {file} erstallt",
    "{user} created {file}" : "Den {user} huet {file} erstallt",
    "{file} was created in a public folder" : "{file} ass an engem ëffentlechen Dossier erstallt ginn",
    "You changed {file}" : "Du hues {file} verännert",
    "{user} changed {file}" : "Den {user} huet {file} verännert",
    "You deleted {file}" : "Du hues {file} geläscht",
    "{user} deleted {file}" : "Den {user} huet {file} geläscht",
    "You restored {file}" : "Du hues {file} erem hier gestallt",
    "{user} restored {file}" : "Den {user} huet {file} erem hier gestallt",
    "You renamed {oldfile} to {newfile}" : "Du hues {oldfile} zu {newfile} embenannt",
    "{user} renamed {oldfile} to {newfile}" : "Den {user} huet {oldfile} zu {newfile} embenannt",
    "You moved {oldfile} to {newfile}" : "Du hues {oldfile} zu {newfile} verreckelt",
    "{user} moved {oldfile} to {newfile}" : "Den {user} huet {oldfile} zu {newfile} verreckelt",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Eng Datei gouf zu dengen Favoriten <strong> dobäigesat </strong> oder aus dengen Favortien <strong> geläscht </strong>",
    "All files" : "All d'Fichieren",
    "Upload (max. %s)" : "Upload (maximal ¦%s)",
    "in %s" : "an %s",
    "Tags" : "Tags",
    "Cancel" : "Ofbriechen",
    "Create" : "Erstellen",
    "Show hidden files" : "Weis déi verstoppten Dateien",
    "WebDAV" : "WebDAV",
    "No files in here" : "Keng Dokumenter hei",
    "Upload some content or sync with your devices!" : "Lued Dateien erop oder synchroniséier se mat dengen Appartaten",
    "No entries found in this folder" : "Keng Elementer an dësem Dossier fonnt",
    "Select all" : "All auswielen",
    "Upload too large" : "Upload ze grouss",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Déi Dateien déi Dir probéiert erop ze lueden sinn méi grouss wei déi Maximal Gréisst déi op dësem Server erlaabt ass.",
    "Files and folders you mark as favorite will show up here" : "Hei gesais du deng Favoriten",
    "Deleted files" : "Geläschten Dateien",
    "Shared with others" : "Mat aaneren gedeelt",
    "Shared with you" : "Mat dir gedeelt",
    "Shared by link" : "Mat engem Link gedeelt",
    "Text file" : "Text Fichier",
    "New text file.txt" : "Neien Text file.txt",
    "Select" : "Auswielen",
    "You don’t have permission to upload or create files here" : "Du hues net genuch Rechter hei Dokumenter eropzelueden oder ze erstellen",
    "New" : "Nei",
    "Settings" : "Astellungen"
},
"nplurals=2; plural=(n != 1);");
